# Metroid Prime Layout Editor

Some Text

Number | Name | Destination
0 | Chozo Ruins West (aka Transport to Tallon Overworld North) |
1 | Chozo Ruins North (aka Transport to Magmoor Caverns North) |
2 | Chozo Ruins East (aka Transport to Tallon Overworld East) |
3 | Chozo Ruins South (aka Transport to Tallon Overworld South) |
4 | Phendrana Drifts North (aka Transport to Magmoor Caverns West) |
5 | Phendrana Drifts South (aka Transport to Magmoor Caverns South) |
6 | Tallon Overworld North (aka Transport to Chozo Ruins West) |
7 | Artifact Temple |
8 | Tallon Overworld East (aka Transport to Chozo Ruins East) |
9 | Tallon Overworld West (aka Transport to Magmoor Caverns East) |
10 | Tallon Overworld South (aka Transport to Chozo Ruins South) |
11 | Tallon Overworld South (aka Transport to Phazon Mines East) |
12 | Phazon Mines East (aka Transport to Tallon Overworld South) |
13 | Phazon Mines West (aka Transport to Magmoor Caverns South) |
14 | Magmoor Caverns North (aka Transport to Chozo Ruins North) |
15 | Magmoor Caverns West (aka Transport to Phendrana Drifts North) |
16 | Magmoor Caverns East (aka Transport to Tallon Overworld West) |
17 | Magmoor Caverns South (aka Transport to Phazon Mines West) |
18 | Magmoor Caverns South (aka Transport to Phendrana Drifts South) |
19 | Crater Entry Point |
-- | Starting point |

Number | Region | Location | Item
0 | Chozo | Main Plaza (Half-Pipe) |
1 | Chozo | Main Plaza (Grapple Ledge) |
2 | Chozo | Main Plaza (Tree) |
3 | Chozo | Main Plaza (Locked Door) |
4 | Chozo | Ruined Fountain |
5 | Chozo | Ruined Shrine ("Beetle Battle") |
6 | Chozo | Ruined Shrine (Half-Pipe) |
7 | Chozo | Ruined Shrine (Lower Tunnel) |
8 | Chozo | Vault |
9 | Chozo | Training Chamber |
10 | Chozo | Ruined Nursery |
11 | Chozo | Training Chamber Access |
12 | Chozo | Magma Pool |
13 | Chozo | Tower of Light |
14 | Chozo | Tower Chamber |
15 | Chozo | Ruined Gallery (Missile Wall) |
16 | Chozo | Ruined Gallery (Tunnel) |
17 | Chozo | Transport Access North |
18 | Chozo | Gathering Hall |
19 | Chozo | Hive Totem |
20 | Chozo | Sunchamber (Flaahgra) |
21 | Chozo | Sunchamber (Ghosts) |
22 | Chozo | Watery Hall Access |
23 | Chozo | Watery Hall (Scan Puzzle) |
24 | Chozo | Watery Hall (Underwater) |
25 | Chozo | Dynamo (Lower) |
26 | Chozo | Dynamo (Spider Track) |
27 | Chozo | Burn Dome (Missile) |
28 | Chozo | Burn Dome (I. Drone) |
29 | Chozo | Furnace (Spider Tracks) |
30 | Chozo | Furnace (Inside Furnace) |
31 | Chozo | Hall of the Elders |
32 | Chozo | Crossway |
33 | Chozo | Elder Chamber |
34 | Chozo | Antechamber |
35 | Phendrana | Phendrana Shorelines (Behind Ice) |
36 | Phendrana | Phendrana Shorelines (Spider Track) |
37 | Phendrana | Chozo Ice Temple |
38 | Phendrana | Ice Ruins West |
39 | Phendrana | Ice Ruins East (Behind Ice) |
40 | Phendrana | Ice Ruins East (Spider Track) |
41 | Phendrana | Chapel of the Elders |
42 | Phendrana | Ruined Courtyard |
43 | Phendrana | Phendrana Canyon |
44 | Phendrana | Quarantine Cave |
45 | Phendrana | Research Lab Hydra |
46 | Phendrana | Quarantine Monitor |
47 | Phendrana | Observatory |
48 | Phendrana | Transport Access |
49 | Phendrana | Control Tower |
50 | Phendrana | Research Core |
51 | Phendrana | Frost Cave |
52 | Phendrana | Research Lab Aether (Tank) |
53 | Phendrana | Research Lab Aether (Morph Track) |
54 | Phendrana | Gravity Chamber (Underwater) |
55 | Phendrana | Gravity Chamber (Grapple Ledge) |
56 | Phendrana | Storage Cave |
57 | Phendrana | Security Cave |
58 | Tallon | Landing Site |
59 | Tallon | Alcove |
60 | Tallon | Frigate Crash Site |
61 | Tallon | Overgrown Cavern |
62 | Tallon | Root Cave |
63 | Tallon | Artifact Temple |
64 | Tallon | Transport Tunnel B |
65 | Tallon | Arbor Chamber |
66 | Tallon | Cargo Freight Lift to Deck Gamma |
67 | Tallon | Biohazard Containment |
68 | Tallon | Hydro Access Tunnel |
69 | Tallon | Great Tree Chamber |
70 | Tallon | Life Grove Tunnel |
71 | Tallon | Life Grove (Start) |
72 | Tallon | Life Grove (Underwater Spinner) |
73 | Mines | Main Quarry |
74 | Mines | Security Access A |
75 | Mines | Storage Depot B |
76 | Mines | Storage Depot A |
77 | Mines | Elite Research (Phazon Elite) |
78 | Mines | Elite Research (Laser) |
79 | Mines | Elite Control Access |
80 | Mines | Ventilation Shaft |
81 | Mines | Phazon Processing Center |
82 | Mines | Processing Center Access |
83 | Mines | Elite Quarters |
84 | Mines | Central Dynamo |
85 | Mines | Metroid Quarantine B |
86 | Mines | Metroid Quarantine A |
87 | Mines | Fungal Hall B |
88 | Mines | Phazon Mining Tunnel |
89 | Mines | Fungal Hall Access |
90 | Magmoor | Lava Lake |
91 | Magmoor | Triclops Pit |
92 | Magmoor | Storage Cavern |
93 | Magmoor | Transport Tunnel A |
94 | Magmoor | Warrior Shrine |
95 | Magmoor | Shore Tunnel |
96 | Magmoor | Fiery Shores (Morph Track) |
97 | Magmoor | Fiery Shores (Warrior Shrine Tunnel) |
98 | Magmoor | Plasma Processing |
99 | Magmoor | Magmoor Workstation |